package org.nst.pasientlink.authenticator.admin.command;

/**
 * <p>Title: AuthenticateSessionCommand</p>
 * <p>Description: authenticate session page logic </p>
 * <p>Copyright: Copyright (c) 2002</p>
 * <p>Company: Norwegian Centre for Telemedicine </p>
 * @author Thomas Strandens, Per Atle Bakkevoll
 * @version 1.0
 *
 */

import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.apache.velocity.context.Context;
import org.apache.velocity.app.tools.*;
import org.nst.pasientlink.authenticator.admin.Controller;
import org.nst.pasientlink.authenticator.Authenticator;

public class AuthenticateSessionCommand extends Command
{
   public static final String TEMPLATE_NAME = "authenticate_session.vm";    //Name of the Template
   private int authenticationReturnValue = -1; // return value from authenticateSession call

   public AuthenticateSessionCommand( HttpServletRequest req, HttpServletResponse resp )
   {
       super(req, resp);
   }

   /**
    * setAuthenticationReturnValue sets the return value from the actual
    * authenticateSession call, performed by the Controller before generating
    * this command object. This value is used to determine what error messages,
    * if any, to show when displaying the page
    */

   public void setAuthenticationReturnValue(int myRetVal) {
      this.authenticationReturnValue = myRetVal;
   }

   public String exec(Context ctx)
   {
      String returnTemplate = TEMPLATE_NAME;
      if(this.authenticationReturnValue != -1) {
         // velocity template need to test for an error and inform user
         ctx.put(RETURN_VALUE, new Integer(this.authenticationReturnValue));
         // return to request auth. page upon unknown and time out errors
         if(this.authenticationReturnValue == Authenticator.AUTHENTICATE_TIMED_OUT ||
            this.authenticationReturnValue == Authenticator.AUTHENTICATE_UNKNOWN_ERROR) {
            returnTemplate = RequestAuthenticationCommand.TEMPLATE_NAME;
         }
      }
      return returnTemplate;
    }
}
