package org.nst.pasientlink.authenticator.admin.command;

/**
 * <p>Title: UserEditCommand </p>
 * <p>Description: logic for UserEditCommand pages</p>
 * <p>Copyright: Copyright (c) 2002</p>
 * <p>Company: </p>
 * @author unascribed
 * @version 1.0
 */
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.apache.velocity.context.Context;
import org.apache.velocity.app.tools.*;
import org.nst.pasientlink.authenticator.admin.Controller;

public class UserDeleteCommand extends Command {
   // constants
   public static final String TEMPLATE_NAME = "user_delete.vm";    //Name of the Template
   public static final String TEMPLATE_NAME_RECEIPT = "user_delete_receipt.vm"; // receipt for completed change
   private static final String PASSWORD_MASK = "******";
   private static final String PARAMETER_OPTION = "option";
   private static final String PARAMETER_SHOW_USER_CONFIRMATION_FORM = "confirmationForm";
   private static final String PARAMETER_OPTION_USER_LOOKUP = "Look up user";
   private static final String PARAMETER_OPTION_USER_DELETE = "Delete user";
   private static final String PARAMETER_USERID = "userID";
   private static final String PARAMETER_PASSWORD = "password";
   private static final String PARAMETER_DESCRIPTION = "description";
   private static final String PARAMETER_GSMSUBSCRIBER_ID = "GSMSubscriberID";
   private static final String RETURN_VALUE_NONEXISTANT_USER = "NONEXISTANT_USER";
   private static final String RETURN_VALUE_ERROR_DELETING_USER = "ERROR_DELETING_USER";
   private static final String RETURN_VALUE_USER_DELETED = "USER_DELETED";

   // instance variables
   String myOption;
   String myUserID;
   String myPassword;
   String myDescription;
   String myGSMSubscriberID;

   public UserDeleteCommand( HttpServletRequest req, HttpServletResponse resp )
   {
       super(req, resp);
   }

   public String exec(Context ctx) {
      String returnTemplate = TEMPLATE_NAME;
      myOption = request.getParameter(this.PARAMETER_OPTION);
      myUserID = request.getParameter(this.PARAMETER_USERID);
      myPassword = request.getParameter(this.PARAMETER_PASSWORD);
      myDescription = request.getParameter(this.PARAMETER_DESCRIPTION);
      myGSMSubscriberID = request.getParameter(this.PARAMETER_GSMSUBSCRIBER_ID);
      if(myOption == null) {
         // template will show the lookup form
      }
      else if(myOption.equalsIgnoreCase(this.PARAMETER_OPTION_USER_DELETE)) {
         putUserParameters(ctx);
         if(myUserID != null && myUserID.trim().length() != 0) {
            if(!this.getAuthenticatorStorage().userExists(myUserID)) {
               ctx.put(this.RETURN_VALUE, this.RETURN_VALUE_NONEXISTANT_USER);
            }
            else {
               boolean retVal = this.getAuthenticatorStorage().removeUser(myUserID);
               if(retVal) { // success, user is gone
                  ctx.put(this.RETURN_VALUE, this.RETURN_VALUE_USER_DELETED);
                  returnTemplate = this.TEMPLATE_NAME_RECEIPT;
               }
               else {
                  ctx.put(this.RETURN_VALUE, this.RETURN_VALUE_ERROR_DELETING_USER);
               }
            }
         }
         else { // missing parameters
            ctx.put(this.RETURN_VALUE, this.RETURN_VALUE_ERROR_DELETING_USER);
         }
      }
      else if(myOption.equalsIgnoreCase(PARAMETER_OPTION_USER_LOOKUP)) {
         if(myUserID != null && myUserID.trim().length() != 0) {
            if(this.getAuthenticatorStorage().userExists(myUserID)) { // user exists
               this.myPassword = this.PASSWORD_MASK;
               this.myDescription = this.getAuthenticatorStorage().getDescription(myUserID);
               this.myGSMSubscriberID = this.getAuthenticatorStorage().getGSMSubscriberID(myUserID);
               putUserParameters(ctx);
               // make template show the complete user form
               ctx.put(this.PARAMETER_SHOW_USER_CONFIRMATION_FORM, new Boolean(true));
            }
            else {
               ctx.put(this.RETURN_VALUE, this.RETURN_VALUE_NONEXISTANT_USER);
            }
         }
         else {
            ctx.put(this.RETURN_VALUE, this.RETURN_VALUE_NONEXISTANT_USER);
         }
      }
      return returnTemplate;
    }

   /**
    * getNextPassword returns a new generated password
    *
    * @return String containing new generated password
    */

   protected String getNextPassword() {
      return Controller.getPasswordGenerator().nextPassword();
   }

   /**
    * putUserParameters puts common user parameters into the context. The
    * instance variables should be populated before this method is called
    */

   private void putUserParameters(Context ctx) {
      ctx.put(this.PARAMETER_USERID, this.myUserID);
      ctx.put(this.PARAMETER_PASSWORD, this.myPassword);
      ctx.put(this.PARAMETER_DESCRIPTION, this.myDescription);
      ctx.put(this.PARAMETER_GSMSUBSCRIBER_ID, this.myGSMSubscriberID);
   }
}
